==> haskell-hslua-module-text-1.1.0.1-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-text
version:              1.1.0.1
visibility:           public
id:                   hslua-module-text-1.1.0.1-8OWNHH5uRsVEVuPziua254
key:                  hslua-module-text-1.1.0.1-8OWNHH5uRsVEVuPziua254
license:              MIT
copyright:            © 2017–2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  a9877242a1d8af57f4b2939a3041d0f4
exposed:              True
exposed-modules:      HsLua.Module.Text
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-text-1.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-text-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-text
hs-libraries:         HShslua-module-text-1.1.0.1-8OWNHH5uRsVEVuPziua254
depends:
    base-4.16.4.0 hslua-core-2.3.1-7tP5g9DQ4OeKdOyVI81TL5
    hslua-marshalling-2.3.1-JCueeqDsAl64rAvJDWOXcX
    hslua-packaging-2.3.1-JrcVYaOwMi2LpAg5X3lhR2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-text-1.1.0.1-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-text
version:              1.1.0.1
visibility:           public
id:                   hslua-module-text-1.1.0.1-9a7uETHIzbv44YJv0fuAnc
key:                  hslua-module-text-1.1.0.1-9a7uETHIzbv44YJv0fuAnc
license:              MIT
copyright:            © 2017–2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  516b33b4c933cc69d4f287e06d3ba67f
exposed:              True
exposed-modules:      HsLua.Module.Text
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-text-1.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-text-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-text
hs-libraries:         HShslua-module-text-1.1.0.1-9a7uETHIzbv44YJv0fuAnc
depends:
    base-4.16.4.0 hslua-core-2.3.1-9wBIA2gFuIxACctfhiAOUi
    hslua-marshalling-2.3.1-GfiIDqwLJTiFJfYGxWLaEk
    hslua-packaging-2.3.1-71WJ8bDD9loCbeXAvu0JlX text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
